@@ -247,7 +247,7 @@ terraform {
     bucket = "tfstate-test"
     key    = "%s/terraform.tfstate"
 
-    // mock s3 endpoint with localstack
+    # mock s3 endpoint with localstack
     endpoint                    = "%s"
     access_key                  = "dummy"
     secret_key                  = "dummy"
@@ -256,27 +256,7 @@ terraform {
     force_path_style            = true
   }
 }
-# https://www.terraform.io/docs/providers/aws/index.html
-# https://www.terraform.io/docs/providers/aws/guides/custom-service-endpoints.html#localstack
-provider "aws" {
-  region = "ap-northeast-1"
-
-  access_key                  = "dummy"
-  secret_key                  = "dummy"
-  skip_credentials_validation = true
-  skip_metadata_api_check     = true
-  skip_region_validation      = true
-  skip_requesting_account_id  = true
-  s3_use_path_style           = true
-
-  // mock endpoints with localstack
-  endpoints {
-    s3  = "%s"
-    ec2 = "%s"
-    iam = "%s"
-  }
-}
-`, dir, endpoint, endpoint, endpoint, endpoint)
+`, dir, endpoint)
 	return backendConfig
 }
 
