@@ -23,10 +23,10 @@ func TestStateMigratorConfigNewMigrator(t *testing.T) {
 			config: &StateMigratorConfig{
 				Dir: "dir1",
 				Actions: []string{
-					"mv aws_security_group.foo aws_security_group.foo2",
-					"mv aws_security_group.bar aws_security_group.bar2",
-					"rm aws_security_group.baz",
-					"import aws_security_group.qux qux",
+					"mv null_resource.foo null_resource.foo2",
+					"mv null_resource.bar null_resource.bar2",
+					"rm time_static.baz",
+					"import time_static.qux 2006-01-02T15:04:05Z",
 				},
 			},
 			o: &MigratorOption{
@@ -39,10 +39,10 @@ func TestStateMigratorConfigNewMigrator(t *testing.T) {
 			config: &StateMigratorConfig{
 				Dir: "",
 				Actions: []string{
-					"mv aws_security_group.foo aws_security_group.foo2",
-					"mv aws_security_group.bar aws_security_group.bar2",
-					"rm aws_security_group.baz",
-					"import aws_security_group.qux qux",
+					"mv null_resource.foo null_resource.foo2",
+					"mv null_resource.bar null_resource.bar2",
+					"rm time_static.baz",
+					"import time_static.qux 2006-01-02T15:04:05Z",
 				},
 			},
 			o: &MigratorOption{
@@ -55,10 +55,10 @@ func TestStateMigratorConfigNewMigrator(t *testing.T) {
 			config: &StateMigratorConfig{
 				Dir: "dir1",
 				Actions: []string{
-					"mv aws_security_group.foo aws_security_group.foo2",
-					"mv aws_security_group.bar aws_security_group.bar2",
-					"rm aws_security_group.baz",
-					"import aws_security_group.qux qux",
+					"mv null_resource.foo null_resource.foo2",
+					"mv null_resource.bar null_resource.bar2",
+					"rm time_static.baz",
+					"import time_static.qux 2006-01-02T15:04:05Z",
 				},
 				Workspace: "workspace1",
 			},
@@ -72,7 +72,7 @@ func TestStateMigratorConfigNewMigrator(t *testing.T) {
 			config: &StateMigratorConfig{
 				Dir: "",
 				Actions: []string{
-					"mv aws_security_group.foo",
+					"mv null_resource.foo",
 				},
 			},
 			o:  nil,
@@ -92,10 +92,10 @@ func TestStateMigratorConfigNewMigrator(t *testing.T) {
 			config: &StateMigratorConfig{
 				Dir: "dir1",
 				Actions: []string{
-					"mv aws_security_group.foo aws_security_group.foo2",
-					"mv aws_security_group.bar aws_security_group.bar2",
-					"rm aws_security_group.baz",
-					"import aws_security_group.qux qux",
+					"mv null_resource.foo null_resource.foo2",
+					"mv null_resource.bar null_resource.bar2",
+					"rm time_static.baz",
+					"import time_static.qux 2006-01-02T15:04:05Z",
 				},
 				Force: true,
 			},
@@ -120,125 +120,35 @@ func TestStateMigratorConfigNewMigrator(t *testing.T) {
 	}
 }
 
-func TestAccStateMigratorApply(t *testing.T) {
-	tfexec.SkipUnlessAcceptanceTestEnabled(t)
-
-	cases := []struct {
-		desc      string
-		workspace string
-	}{
-		{
-			desc:      "default workspace",
-			workspace: "default",
-		},
-		{
-			desc:      "non-default workspace",
-			workspace: "workspace1",
-		},
-	}
-
-	for _, tc := range cases {
-		t.Run(tc.desc, func(t *testing.T) {
-			backend := tfexec.GetTestAccBackendS3Config(t.Name())
-
-			source := `
-resource "aws_security_group" "foo" {}
-resource "aws_security_group" "bar" {}
-resource "aws_security_group" "baz" {}
-resource "aws_iam_user" "qux" {
-	name = "qux"
-}
-`
-			tf := tfexec.SetupTestAccWithApply(t, tc.workspace, backend+source)
-			ctx := context.Background()
-
-			updatedSource := `
-resource "aws_security_group" "foo2" {}
-resource "aws_security_group" "baz" {}
-resource "aws_iam_user" "qux" {
-	name = "qux"
-}
-`
-
-			tfexec.UpdateTestAccSource(t, tf, backend+updatedSource)
-
-			_, err := tf.StateRm(ctx, nil, []string{"aws_iam_user.qux"})
-			if err != nil {
-				t.Fatalf("failed to run terraform state rm: %s", err)
-			}
-
-			changed, err := tf.PlanHasChange(ctx, nil)
-			if err != nil {
-				t.Fatalf("failed to run PlanHasChange: %s", err)
-			}
-			if !changed {
-				t.Fatalf("expect to have changes")
-			}
-
-			actions := []StateAction{
-				NewStateMvAction("aws_security_group.foo", "aws_security_group.foo2"),
-				NewStateRmAction([]string{"aws_security_group.bar"}),
-				NewStateImportAction("aws_iam_user.qux", "qux"),
-			}
-
-			m := NewStateMigrator(tf.Dir(), tc.workspace, actions, &MigratorOption{}, false)
-			err = m.Plan(ctx)
-			if err != nil {
-				t.Fatalf("failed to run migrator plan: %s", err)
-			}
-
-			err = m.Apply(ctx)
-			if err != nil {
-				t.Fatalf("failed to run migrator apply: %s", err)
-			}
-
-			got, err := tf.StateList(ctx, nil, nil)
-			if err != nil {
-				t.Fatalf("failed to run terraform state list: %s", err)
-			}
-
-			want := []string{
-				"aws_security_group.foo2",
-				"aws_security_group.baz",
-				"aws_iam_user.qux",
-			}
-			sort.Strings(got)
-			sort.Strings(want)
-			if !reflect.DeepEqual(got, want) {
-				t.Errorf("got state: %v, want state: %v", got, want)
-			}
-
-			changed, err = tf.PlanHasChange(ctx, nil)
-			if err != nil {
-				t.Fatalf("failed to run PlanHasChange: %s", err)
-			}
-			if changed {
-				t.Fatalf("expect not to have changes")
-			}
-		})
-	}
-}
-
-func TestAccStateMigratorApplyForce(t *testing.T) {
+func TestAccStateMigratorApplySimple(t *testing.T) {
 	tfexec.SkipUnlessAcceptanceTestEnabled(t)
 
 	backend := tfexec.GetTestAccBackendS3Config(t.Name())
 
 	source := `
-resource "aws_security_group" "foo" {}
-resource "aws_security_group" "bar" {}
+resource "null_resource" "foo" {}
+resource "null_resource" "bar" {}
+resource "null_resource" "baz" {}
+resource "time_static" "qux" { triggers = {} }
 `
-	tf := tfexec.SetupTestAccWithApply(t, "default", backend+source)
+
+	workspace := "default"
+	tf := tfexec.SetupTestAccWithApply(t, workspace, backend+source)
 	ctx := context.Background()
 
 	updatedSource := `
-resource "aws_security_group" "foo2" {}
-resource "aws_security_group" "bar" {}
-resource "aws_security_group" "baz" {}
+resource "null_resource" "foo2" {}
+resource "null_resource" "baz" {}
+resource "time_static" "qux" { triggers = {} }
 `
 
 	tfexec.UpdateTestAccSource(t, tf, backend+updatedSource)
 
+	_, err := tf.StateRm(ctx, nil, []string{"time_static.qux"})
+	if err != nil {
+		t.Fatalf("failed to run terraform state rm: %s", err)
+	}
+
 	changed, err := tf.PlanHasChange(ctx, nil)
 	if err != nil {
 		t.Fatalf("failed to run PlanHasChange: %s", err)
@@ -248,13 +158,13 @@ resource "aws_security_group" "baz" {}
 	}
 
 	actions := []StateAction{
-		NewStateMvAction("aws_security_group.foo", "aws_security_group.foo2"),
+		NewStateMvAction("null_resource.foo", "null_resource.foo2"),
+		NewStateRmAction([]string{"null_resource.bar"}),
+		NewStateImportAction("time_static.qux", "2006-01-02T15:04:05Z"),
 	}
 
-	o := &MigratorOption{}
-	o.PlanOut = "foo.tfplan"
-
-	m := NewStateMigrator(tf.Dir(), "default", actions, o, true)
+	force := false
+	m := NewStateMigrator(tf.Dir(), workspace, actions, &MigratorOption{}, force)
 	err = m.Plan(ctx)
 	if err != nil {
 		t.Fatalf("failed to run migrator plan: %s", err)
@@ -271,8 +181,150 @@ resource "aws_security_group" "baz" {}
 	}
 
 	want := []string{
-		"aws_security_group.foo2",
-		"aws_security_group.bar",
+		"null_resource.foo2",
+		"null_resource.baz",
+		"time_static.qux",
+	}
+	sort.Strings(got)
+	sort.Strings(want)
+	if !reflect.DeepEqual(got, want) {
+		t.Errorf("got state: %v, want state: %v", got, want)
+	}
+
+	changed, err = tf.PlanHasChange(ctx, nil)
+	if err != nil {
+		t.Fatalf("failed to run PlanHasChange: %s", err)
+	}
+	if changed {
+		t.Fatalf("expect not to have changes")
+	}
+}
+
+func TestAccStateMigratorApplyWithWorkspace(t *testing.T) {
+	tfexec.SkipUnlessAcceptanceTestEnabled(t)
+
+	backend := tfexec.GetTestAccBackendS3Config(t.Name())
+
+	source := `
+resource "null_resource" "foo" {}
+resource "null_resource" "bar" {}
+`
+
+	workspace := "workspace1"
+	tf := tfexec.SetupTestAccWithApply(t, workspace, backend+source)
+	ctx := context.Background()
+
+	updatedSource := `
+resource "null_resource" "foo2" {}
+resource "null_resource" "bar" {}
+`
+
+	tfexec.UpdateTestAccSource(t, tf, backend+updatedSource)
+
+	changed, err := tf.PlanHasChange(ctx, nil)
+	if err != nil {
+		t.Fatalf("failed to run PlanHasChange: %s", err)
+	}
+	if !changed {
+		t.Fatalf("expect to have changes")
+	}
+
+	actions := []StateAction{
+		NewStateMvAction("null_resource.foo", "null_resource.foo2"),
+	}
+
+	force := false
+	m := NewStateMigrator(tf.Dir(), workspace, actions, &MigratorOption{}, force)
+	err = m.Plan(ctx)
+	if err != nil {
+		t.Fatalf("failed to run migrator plan: %s", err)
+	}
+
+	err = m.Apply(ctx)
+	if err != nil {
+		t.Fatalf("failed to run migrator apply: %s", err)
+	}
+
+	got, err := tf.StateList(ctx, nil, nil)
+	if err != nil {
+		t.Fatalf("failed to run terraform state list: %s", err)
+	}
+
+	want := []string{
+		"null_resource.foo2",
+		"null_resource.bar",
+	}
+	sort.Strings(got)
+	sort.Strings(want)
+	if !reflect.DeepEqual(got, want) {
+		t.Errorf("got state: %v, want state: %v", got, want)
+	}
+
+	changed, err = tf.PlanHasChange(ctx, nil)
+	if err != nil {
+		t.Fatalf("failed to run PlanHasChange: %s", err)
+	}
+	if changed {
+		t.Fatalf("expect not to have changes")
+	}
+}
+
+func TestAccStateMigratorApplyWithForce(t *testing.T) {
+	tfexec.SkipUnlessAcceptanceTestEnabled(t)
+
+	backend := tfexec.GetTestAccBackendS3Config(t.Name())
+
+	source := `
+resource "null_resource" "foo" {}
+resource "null_resource" "bar" {}
+`
+
+	workspace := "default"
+	tf := tfexec.SetupTestAccWithApply(t, workspace, backend+source)
+	ctx := context.Background()
+
+	updatedSource := `
+resource "null_resource" "foo2" {}
+resource "null_resource" "bar" {}
+resource "null_resource" "baz" {}
+`
+
+	tfexec.UpdateTestAccSource(t, tf, backend+updatedSource)
+
+	changed, err := tf.PlanHasChange(ctx, nil)
+	if err != nil {
+		t.Fatalf("failed to run PlanHasChange: %s", err)
+	}
+	if !changed {
+		t.Fatalf("expect to have changes")
+	}
+
+	actions := []StateAction{
+		NewStateMvAction("null_resource.foo", "null_resource.foo2"),
+	}
+
+	o := &MigratorOption{}
+	o.PlanOut = "foo.tfplan"
+	force := true
+	m := NewStateMigrator(tf.Dir(), workspace, actions, o, force)
+	err = m.Plan(ctx)
+	if err != nil {
+		t.Fatalf("failed to run migrator plan: %s", err)
+	}
+
+	err = m.Apply(ctx)
+	if err != nil {
+		t.Fatalf("failed to run migrator apply: %s", err)
+	}
+
+	got, err := tf.StateList(ctx, nil, nil)
+	if err != nil {
+		t.Fatalf("failed to run terraform state list: %s", err)
+	}
+
+	want := []string{
+		"null_resource.foo2",
+		"null_resource.bar",
 	}
 	sort.Strings(got)
 	sort.Strings(want)
